## 1.0.0 - 2024-02-12

### Added

- [#1079](https://github.com/edgarrmondragon/citric/issues/1079) Added `get_db_version` method to RPC client
- [#1092](https://github.com/edgarrmondragon/citric/issues/1092) Added a `Session.call` method to allow calling RPC methods without any error handling to get the raw response

### Removed

- [#1093](https://github.com/edgarrmondragon/citric/issues/1093) Removed the `Session._headers` attribute

### Documentation

- [#1057](https://github.com/edgarrmondragon/citric/issues/1057) Documented `conda install` option
- [#1092](https://github.com/edgarrmondragon/citric/issues/1092) Linked unimplemented methods to `Session.call` examples
